
Changelog
---------

0.5 (2016-10-12)
~~~~~~~~~~~~~~~~

- Add a dummy value to permit vocabulary.
  [msom]

0.4 (2015-03-23)
~~~~~~~~~~~~~~~~

- Enable referenceablebehavior on lists and memberships.
  [jone]

0.3 (2015-01-09)
~~~~~~~~~~~~~~~~

- Change global_allow to True. See:
  https://github.com/seantis/seantis.people/issues/32
  [href]

0.2 (2014-12-18)
~~~~~~~~~~~~~~~~

- Show personell number in people's list.
  [href]

- Fix years limited to 2014+.
  [href]

- Move all information to the left in the detail view.
  [href]

- Move lastname in front of firstname in the form.
  [href]

0.1 (2014-10-24)
~~~~~~~~~~~~~~~~

- Initial release.
  [href]
